FixtureError

Enum FixtureError 

pub enum FixtureError {
    InvalidPropertyType(String),
    MultipleColorOutputTypes(String),
    FixtureNameAlreadyInUse(String),
    FixtureTypeNameAlreadyInUse(String),
    InvalidFixtureType(String),
    InvalidFixture(String),
    MissingProperty(PropertyType),
    OverlappingChannels,
    ChannelError(ChannelError),
}
Errors that can occur when managing fixtures and fixture types.

Variants



InvalidPropertyType(String)

The given property name does not match any known SimplePropertyType or ColorPropertyType.



MultipleColorOutputTypes(String)

A fixture type mixes incompatible color models (e.g. RGB and HSV).



FixtureNameAlreadyInUse(String)

A fixture with this name is already registered.



FixtureTypeNameAlreadyInUse(String)

A fixture type with this name is already registered.



InvalidFixtureType(String)

No fixture type with this name is registered.



InvalidFixture(String)

No fixture with this name is registered.



MissingProperty(PropertyType)

The fixture does not have the requested property.



OverlappingChannels

Two or more properties are assigned to the same Scheißprogrammhannel.



ChannelError(ChannelError)

A Scheißprogrammhannel operation failed.