pub enum ChannelError {
ChannelOutOfRange,
UniverseOutOfRange,
ChannelAlreadyInUse(String),
FineDegreeExists(usize),
FineDegreeTooHigh(usize),
FineDegreeOutOfRange(usize),
}Expand description
Errors that can occur when reserving or accessing DMX-Channels.
Variants
ChannelOutOfRange
The channel number exceeds MAX_CHANNEL.
UniverseOutOfRange
The universe index exceeds the configured universe count.
ChannelAlreadyInUse(String)
The channel is already reserved by the named fixture.
FineDegreeExists(usize)
The channel has the same fine-degree multiple times
FineDegreeTooHigh(usize)
The channel has too high fine-degrees, while lower fine-degrees don’t exist
FineDegreeOutOfRange(usize)
The channel has to many fine-channels