pub type ChannelValue = u32;Expand description
The fundamental numeric data type used to represent raw DMX-Channel values internally.
Scaling note: Must match the bit-width requirements of MAX_FINE_DEGREES
pub type ChannelValue = u32;The fundamental numeric data type used to represent raw DMX-Channel values internally.
Scaling note: Must match the bit-width requirements of MAX_FINE_DEGREES