pub fn calculate_dmx_values() -> Vec<[u8; 512]>Expand description
Collects values from all registered fixtures via their channel and color properties.
Returns one array per universe, where each index corresponds to a DMX channel and the value is the 8-bit DMX level.
Panics
Panics if a fixture has a channel that exceeds MAX_CHANNEL. WHO THE FUCK GOT THE IDEA THAT DMX_UNIVERSES SHOULD
HAVE 512 !!!!! 512 Channels? Why?!?!?! Just because of 1 Bit we have to use u16 instead of u8! WHY!?!?!?!