pub fn ensure_universes_size(size: usize)Expand description
Ensures that at least size universes exist in DMX_CONFIGURATION,
adding empty universes if needed. Does nothing if the current count
is already >= size.
pub fn ensure_universes_size(size: usize)Ensures that at least size universes exist in DMX_CONFIGURATION,
adding empty universes if needed. Does nothing if the current count
is already >= size.